==> haskell-raw-strings-qq-1.1-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-4h8ssWiXHUPE9muxhYrFuJ
key:                  raw-strings-qq-1.1-4h8ssWiXHUPE9muxhYrFuJ
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  7e88fea7fcd528b9d515736e0b21de88
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-8.10.3/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/raw-strings-qq-1.1
hs-libraries:         HSraw-strings-qq-1.1-4h8ssWiXHUPE9muxhYrFuJ
depends:              base-4.14.1.0 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-raw-strings-qq-1.1-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-IPIEL6T2x8EJdHzeTFVW2K
key:                  raw-strings-qq-1.1-IPIEL6T2x8EJdHzeTFVW2K
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  e89d2342f27f09cc59ddd3c5ee40d4bf
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-8.10.4/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/raw-strings-qq-1.1
hs-libraries:         HSraw-strings-qq-1.1-IPIEL6T2x8EJdHzeTFVW2K
depends:              base-4.14.1.0 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
